@@ -142,7 +142,7 @@ def processSync(group_name, arguments) -> bool:
             file.write(base64.decodebytes(arguments["file_data"].encode()))
             file.close()
 
-            if file_type == "subreports":
+            if file_type == "subreports" and file_path.endswith(".jrxml"):
                 # compilamos el subreport.
                 config = jasper_config.Config()
                 config.output = file_path_compiled
@@ -279,7 +279,7 @@ def printerRequest(**kwargs) -> str:
                 only_pdf,
                 group_name,
                 kwargs["report_name"],
-                kwargs["params"] if "params" in kwargs_names else None,
+                kwargs["params"] if "params" in kwargs_names else {},
             )
         except Exception as error:
             result = str(error)
